@@ -9,7 +9,7 @@ from trade.executor.TradeExecutor import TradeExecutor
 class TradeConductor:
 
     def __init__(self, options, trade_repository: TradeRepository, trade_executor: TradeExecutor):
-        self.log = logging.getLogger(__name__)
+        self.log = logging.getLogger('TradeConductor')
         self.options = options
         self.trade_repository = trade_repository
         self.trade_executor = trade_executor
@@ -22,9 +22,10 @@ class TradeConductor:
 
     def perform_trade(self):
         trade = self.fetch_trade_to_submit()
+        # todo: handle predict mode
         if trade is not None and trade.status == Status.NEW:
             self.log.info(f'About to execute trade:[{trade}]')
             updated_trade = self.trade_executor.trade(trade)
             self.store_submitted_trade(updated_trade)
         else:
-            self.log.warning(f'Trade is not new, so will not trade -> {trade}')
+            self.log.debug(f'Trade is not new, so will not trade -> {trade}')
